##################################
Oxford Instruments Base Instrument
##################################

.. autoclass:: pymeasure.instruments.oxfordinstruments.base.OxfordInstrumentsBase
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.oxfordinstruments.base.OxfordVISAError
    :members:
    :show-inheritance:
